@@ -1,6 +1,6 @@
 
 package Importer::Zim::Unit;
-$Importer::Zim::Unit::VERSION = '0.3.0';
+$Importer::Zim::Unit::VERSION = '0.4.0';
 # ABSTRACT: Import functions with compilation unit scope
 
 use 5.010001;
@@ -23,8 +23,20 @@ sub import {
     my @exports = $class->_prepare_args(@_);
 
     my $caller = caller;
-    my $old    = Sub::Replace::sub_replace(
-        map { ; "${caller}::$_->{export}" => $_->{code} } @exports );
+    return _export_to(    #
+        map { ; "${caller}::$_->{export}" => $_->{code} } @exports
+    );
+}
+
+sub export_to {
+    my $t = shift;
+    @_ = %{ $_[0] } if @_ == 1 && ref $_[0] eq 'HASH';
+    @_ = map { $_ & 1 ? $_[$_] : "${t}::$_[$_]" } 0 .. $#_;
+    goto &_export_to;
+}
+
+sub _export_to {
+    my $old = Sub::Replace::sub_replace(@_);
 
     # Clean it up after compilation
     Devel::Hook->unshift_UNITCHECK_hook(
@@ -141,7 +153,7 @@ Importer::Zim::Unit - Import functions with compilation unit scope
 
 =head1 VERSION
 
-version 0.3.0
+version 0.4.0
 
 =head1 SYNOPSIS
 
